==> open-xchange-dav_7.10.0.orig.tar.bz2: open-xchange-dav-7.10.0/com.openexchange.carddav/src/com/openexchange/carddav/mixins/BulkRequests.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.carddav.mixins;

import com.openexchange.carddav.CarddavProtocol;
import com.openexchange.carddav.GroupwareCarddavFactory;
import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;

/**
 * {@link BulkRequests}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.8.1
 */
public class BulkRequests extends SingleXMLPropertyMixin {

	private final GroupwareCarddavFactory factory;

    /**
     * Initializes a new {@link BulkRequests}.
     *
     * @param factory A reference to the CardDAV factory
     */
    public BulkRequests(GroupwareCarddavFactory factory) {
        super(CarddavProtocol.ME_NS.getURI(), "bulk-requests");
        this.factory = factory;
    }

    @Override
    protected String getValue() {
        long maxUploadSize = factory.getState().getMaxUploadSize();
        return new StringBuilder()
            .append("<MM:simple>")
                .append("<MM:max-resources/>")
                .append(0 >= maxUploadSize ? "<MM:max-bytes/>" : "<MM:max-bytes>" + maxUploadSize + "</MM:max-bytes>")
            .append("</MM:simple>")
        .toString();
    }

}

==> open-xchange-dav_7.10.4.orig.tar.bz2: open-xchange-dav-7.10.4/com.openexchange.carddav/src/com/openexchange/carddav/mixins/BulkRequests.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.carddav.mixins;

import com.openexchange.carddav.CarddavProtocol;
import com.openexchange.carddav.GroupwareCarddavFactory;
import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;

/**
 * {@link BulkRequests}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.8.1
 */
public class BulkRequests extends SingleXMLPropertyMixin {

    /** An integer value representing the maximum number of resources that can be specified in the bulk import request */
    private static final int MAX_RESOURCES = 50;

	private final GroupwareCarddavFactory factory;

    /**
     * Initializes a new {@link BulkRequests}.
     *
     * @param factory A reference to the CardDAV factory
     */
    public BulkRequests(GroupwareCarddavFactory factory) {
        super(CarddavProtocol.ME_NS.getURI(), "bulk-requests");
        this.factory = factory;
    }

    @Override
    protected String getValue() {
        long maxUploadSize = factory.getState().getMaxUploadSize();
        int maxResources = MAX_RESOURCES;
        return new StringBuilder()
            .append("<MM:simple>")
            .append(0 >= maxResources ? "<MM:max-resources/>" : "<MM:max-resources>" + maxResources + "</MM:max-resources>")
            .append(0 >= maxUploadSize ? "<MM:max-bytes/>" : "<MM:max-bytes>" + maxUploadSize + "</MM:max-bytes>")
            .append("</MM:simple>")
        .toString();
    }

}
